@@ -22,6 +22,7 @@ from .hypem import HypemIE
 from .ina import InaIE
 from .infoq import InfoQIE
 from .justintv import JustinTVIE
+from .jukebox import JukeboxIE
 from .keek import KeekIE
 from .liveleak import LiveLeakIE
 from .metacafe import MetacafeIE
@@ -127,6 +128,7 @@ def gen_extractors():
         StatigramIE(),
         BreakIE(),
         VevoIE(),
+        JukeboxIE(),
         GenericIE()
     ]
 
